# Dataset Viewer

Allow to view a dataset image by image and edit their labels using napari

## Install

It is recommended to install the dataset viewer into a virtual environment. To install, run: 

```sh
python -m pip install "dataset_viewer[gui]"
```
